@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_swf.paginator import (
     GetWorkflowExecutionHistoryPaginator,
@@ -64,29 +64,29 @@ __all__ = ("SWFClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    DefaultUndefinedFault: Boto3ClientError
-    DomainAlreadyExistsFault: Boto3ClientError
-    DomainDeprecatedFault: Boto3ClientError
-    LimitExceededFault: Boto3ClientError
-    OperationNotPermittedFault: Boto3ClientError
-    TooManyTagsFault: Boto3ClientError
-    TypeAlreadyExistsFault: Boto3ClientError
-    TypeDeprecatedFault: Boto3ClientError
-    UnknownResourceFault: Boto3ClientError
-    WorkflowExecutionAlreadyStartedFault: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    DefaultUndefinedFault: Type[Boto3ClientError]
+    DomainAlreadyExistsFault: Type[Boto3ClientError]
+    DomainDeprecatedFault: Type[Boto3ClientError]
+    LimitExceededFault: Type[Boto3ClientError]
+    OperationNotPermittedFault: Type[Boto3ClientError]
+    TooManyTagsFault: Type[Boto3ClientError]
+    TypeAlreadyExistsFault: Type[Boto3ClientError]
+    TypeDeprecatedFault: Type[Boto3ClientError]
+    UnknownResourceFault: Type[Boto3ClientError]
+    WorkflowExecutionAlreadyStartedFault: Type[Boto3ClientError]
 
 
 class SWFClient:
     """
-    [SWF.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client)
+    [SWF.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.can_paginate)
         """
 
     def count_closed_workflow_executions(
@@ -100,7 +100,7 @@ class SWFClient:
         closeStatusFilter: CloseStatusFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
+        [Client.count_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
         """
 
     def count_open_workflow_executions(
@@ -112,62 +112,62 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionCountTypeDef:
         """
-        [Client.count_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
+        [Client.count_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
         """
 
     def count_pending_activity_tasks(
         self, domain: str, taskList: TaskListTypeDef
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_activity_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
+        [Client.count_pending_activity_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
         """
 
     def count_pending_decision_tasks(
         self, domain: str, taskList: TaskListTypeDef
     ) -> PendingTaskCountTypeDef:
         """
-        [Client.count_pending_decision_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
+        [Client.count_pending_decision_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
         """
 
     def deprecate_activity_type(self, domain: str, activityType: ActivityTypeTypeDef) -> None:
         """
-        [Client.deprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.deprecate_activity_type)
+        [Client.deprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.deprecate_activity_type)
         """
 
     def deprecate_domain(self, name: str) -> None:
         """
-        [Client.deprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.deprecate_domain)
+        [Client.deprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.deprecate_domain)
         """
 
     def deprecate_workflow_type(self, domain: str, workflowType: WorkflowTypeTypeDef) -> None:
         """
-        [Client.deprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
+        [Client.deprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
         """
 
     def describe_activity_type(
         self, domain: str, activityType: ActivityTypeTypeDef
     ) -> ActivityTypeDetailTypeDef:
         """
-        [Client.describe_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.describe_activity_type)
+        [Client.describe_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.describe_activity_type)
         """
 
     def describe_domain(self, name: str) -> DomainDetailTypeDef:
         """
-        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.describe_domain)
+        [Client.describe_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.describe_domain)
         """
 
     def describe_workflow_execution(
         self, domain: str, execution: WorkflowExecutionTypeDef
     ) -> WorkflowExecutionDetailTypeDef:
         """
-        [Client.describe_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.describe_workflow_execution)
+        [Client.describe_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.describe_workflow_execution)
         """
 
     def describe_workflow_type(
         self, domain: str, workflowType: WorkflowTypeTypeDef
     ) -> WorkflowTypeDetailTypeDef:
         """
-        [Client.describe_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.describe_workflow_type)
+        [Client.describe_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.describe_workflow_type)
         """
 
     def generate_presigned_url(
@@ -178,7 +178,7 @@ class SWFClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.generate_presigned_url)
         """
 
     def get_workflow_execution_history(
@@ -190,7 +190,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> HistoryTypeDef:
         """
-        [Client.get_workflow_execution_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
+        [Client.get_workflow_execution_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
         """
 
     def list_activity_types(
@@ -203,7 +203,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> ActivityTypeInfosTypeDef:
         """
-        [Client.list_activity_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_activity_types)
+        [Client.list_activity_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_activity_types)
         """
 
     def list_closed_workflow_executions(
@@ -220,7 +220,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
+        [Client.list_closed_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
         """
 
     def list_domains(
@@ -231,7 +231,7 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> DomainInfosTypeDef:
         """
-        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_domains)
+        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_domains)
         """
 
     def list_open_workflow_executions(
@@ -246,12 +246,12 @@ class SWFClient:
         executionFilter: WorkflowExecutionFilterTypeDef = None,
     ) -> WorkflowExecutionInfosTypeDef:
         """
-        [Client.list_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
+        [Client.list_open_workflow_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceOutputTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_tags_for_resource)
         """
 
     def list_workflow_types(
@@ -264,14 +264,14 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> WorkflowTypeInfosTypeDef:
         """
-        [Client.list_workflow_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.list_workflow_types)
+        [Client.list_workflow_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.list_workflow_types)
         """
 
     def poll_for_activity_task(
         self, domain: str, taskList: TaskListTypeDef, identity: str = None
     ) -> ActivityTaskTypeDef:
         """
-        [Client.poll_for_activity_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.poll_for_activity_task)
+        [Client.poll_for_activity_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.poll_for_activity_task)
         """
 
     def poll_for_decision_task(
@@ -284,14 +284,14 @@ class SWFClient:
         reverseOrder: bool = None,
     ) -> DecisionTaskTypeDef:
         """
-        [Client.poll_for_decision_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.poll_for_decision_task)
+        [Client.poll_for_decision_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.poll_for_decision_task)
         """
 
     def record_activity_task_heartbeat(
         self, taskToken: str, details: str = None
     ) -> ActivityTaskStatusTypeDef:
         """
-        [Client.record_activity_task_heartbeat documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
+        [Client.record_activity_task_heartbeat documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
         """
 
     def register_activity_type(
@@ -308,7 +308,7 @@ class SWFClient:
         defaultTaskScheduleToCloseTimeout: str = None,
     ) -> None:
         """
-        [Client.register_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.register_activity_type)
+        [Client.register_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.register_activity_type)
         """
 
     def register_domain(
@@ -319,7 +319,7 @@ class SWFClient:
         tags: List[ResourceTagTypeDef] = None,
     ) -> None:
         """
-        [Client.register_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.register_domain)
+        [Client.register_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.register_domain)
         """
 
     def register_workflow_type(
@@ -336,45 +336,45 @@ class SWFClient:
         defaultLambdaRole: str = None,
     ) -> None:
         """
-        [Client.register_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.register_workflow_type)
+        [Client.register_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.register_workflow_type)
         """
 
     def request_cancel_workflow_execution(
         self, domain: str, workflowId: str, runId: str = None
     ) -> None:
         """
-        [Client.request_cancel_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
+        [Client.request_cancel_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
         """
 
     def respond_activity_task_canceled(self, taskToken: str, details: str = None) -> None:
         """
-        [Client.respond_activity_task_canceled documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
+        [Client.respond_activity_task_canceled documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
         """
 
     def respond_activity_task_completed(self, taskToken: str, result: str = None) -> None:
         """
-        [Client.respond_activity_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
+        [Client.respond_activity_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
         """
 
     def respond_activity_task_failed(
         self, taskToken: str, reason: str = None, details: str = None
     ) -> None:
         """
-        [Client.respond_activity_task_failed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
+        [Client.respond_activity_task_failed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
         """
 
     def respond_decision_task_completed(
         self, taskToken: str, decisions: List[DecisionTypeDef] = None, executionContext: str = None
     ) -> None:
         """
-        [Client.respond_decision_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
+        [Client.respond_decision_task_completed documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
         """
 
     def signal_workflow_execution(
         self, domain: str, workflowId: str, signalName: str, runId: str = None, input: str = None
     ) -> None:
         """
-        [Client.signal_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.signal_workflow_execution)
+        [Client.signal_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.signal_workflow_execution)
         """
 
     def start_workflow_execution(
@@ -392,12 +392,12 @@ class SWFClient:
         lambdaRole: str = None,
     ) -> RunTypeDef:
         """
-        [Client.start_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.start_workflow_execution)
+        [Client.start_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.start_workflow_execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: List[ResourceTagTypeDef]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.tag_resource)
         """
 
     def terminate_workflow_execution(
@@ -410,27 +410,27 @@ class SWFClient:
         childPolicy: Literal["TERMINATE", "REQUEST_CANCEL", "ABANDON"] = None,
     ) -> None:
         """
-        [Client.terminate_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
+        [Client.terminate_workflow_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
         """
 
     def undeprecate_activity_type(self, domain: str, activityType: ActivityTypeTypeDef) -> None:
         """
-        [Client.undeprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
+        [Client.undeprecate_activity_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
         """
 
     def undeprecate_domain(self, name: str) -> None:
         """
-        [Client.undeprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.undeprecate_domain)
+        [Client.undeprecate_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.undeprecate_domain)
         """
 
     def undeprecate_workflow_type(self, domain: str, workflowType: WorkflowTypeTypeDef) -> None:
         """
-        [Client.undeprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
+        [Client.undeprecate_workflow_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Client.untag_resource)
         """
 
     @overload
@@ -438,7 +438,7 @@ class SWFClient:
         self, operation_name: Literal["get_workflow_execution_history"]
     ) -> GetWorkflowExecutionHistoryPaginator:
         """
-        [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+        [Paginator.GetWorkflowExecutionHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
         """
 
     @overload
@@ -446,7 +446,7 @@ class SWFClient:
         self, operation_name: Literal["list_activity_types"]
     ) -> ListActivityTypesPaginator:
         """
-        [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+        [Paginator.ListActivityTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
         """
 
     @overload
@@ -454,13 +454,13 @@ class SWFClient:
         self, operation_name: Literal["list_closed_workflow_executions"]
     ) -> ListClosedWorkflowExecutionsPaginator:
         """
-        [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+        [Paginator.ListClosedWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.ListDomains)
+        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.ListDomains)
         """
 
     @overload
@@ -468,7 +468,7 @@ class SWFClient:
         self, operation_name: Literal["list_open_workflow_executions"]
     ) -> ListOpenWorkflowExecutionsPaginator:
         """
-        [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+        [Paginator.ListOpenWorkflowExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
         """
 
     @overload
@@ -476,7 +476,7 @@ class SWFClient:
         self, operation_name: Literal["list_workflow_types"]
     ) -> ListWorkflowTypesPaginator:
         """
-        [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+        [Paginator.ListWorkflowTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
         """
 
     @overload
@@ -484,5 +484,5 @@ class SWFClient:
         self, operation_name: Literal["poll_for_decision_task"]
     ) -> PollForDecisionTaskPaginator:
         """
-        [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+        [Paginator.PollForDecisionTask documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.0/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
         """
